Index: src/lemon/alteration_observer_registry.h
===================================================================
--- src/lemon/alteration_observer_registry.h	(revision 1022)
+++ src/lemon/alteration_observer_registry.h	(revision 1038)
@@ -1,4 +1,4 @@
 /* -*- C++ -*-
  * src/lemon/observer_registry.h - Part of LEMON, a generic C++ optimization library
  *
  * Copyright (C) 2004 Egervary Jeno Kombinatorikus Optimalizalasi Kutatocsoport
@@ -37,5 +37,5 @@
   /// alterations in a container. The alteration observers can be attached
   /// to and detached from the registry. The observers have to inherit
   /// from the \ref AlterationObserverRegistry::ObserverBase and override
   /// the virtual functions in that.
   ///
@@ -50,5 +50,5 @@
 
   template <typename _Item>
-  class AlterationObserverRegistry {
+  class AlterationNotifier {
   public:
     typedef _Item Item;
@@ -73,7 +73,7 @@
     class ObserverBase {
     protected:
-      typedef AlterationObserverRegistry Registry;
-
-      friend class AlterationObserverRegistry;
+      typedef AlterationNotifier Registry;
+
+      friend class AlterationNotifier;
 
       /// Default constructor.
@@ -85,16 +85,16 @@
       virtual ~ObserverBase() {}
 
-      /// Attaches the observer into an AlterationObserverRegistry.
-
-      /// This member attaches the observer into an AlterationObserverRegistry.
-      ///
-      void attach(AlterationObserverRegistry& r) {
+      /// Attaches the observer into an AlterationNotifier.
+
+      /// This member attaches the observer into an AlterationNotifier.
+      ///
+      void attach(AlterationNotifier& r) {
 	registry = &r;
 	registry->attach(*this);
       }
 
-      /// Detaches the observer into an AlterationObserverRegistry.
-
-      /// This member detaches the observer from an AlterationObserverRegistry.
+      /// Detaches the observer into an AlterationNotifier.
+
+      /// This member detaches the observer from an AlterationNotifier.
       ///
       void detach() {
@@ -179,21 +179,21 @@
 	
     ///
     /// The default constructor of the AlterationObserverRegistry. 
     /// It creates an empty registry.
-    AlterationObserverRegistry() {}
-
-    /// Copy Constructor of the AlterationObserverRegistry. 
-	
-    /// Copy constructor of the AlterationObserverRegistry. 
+    AlterationNotifier() {}
+
+    /// Copy Constructor of the AlterationNotifier. 
+	
+    /// Copy constructor of the AlterationNotifier. 
     /// It creates only an empty registry because the copiable
     /// registry's observers have to be registered still into that registry.
-    AlterationObserverRegistry(const AlterationObserverRegistry&) {}
+    AlterationNotifier(const AlterationObserverRegistry&) {}
 
     /// Assign operator.
 		
     /// Assign operator for the AlterationObserverRegistry. 
     /// It makes the registry only empty because the copiable
     /// registry's observers have to be registered still into that registry.
-    AlterationObserverRegistry& operator=(const AlterationObserverRegistry&) {
+    AlterationNotifier& operator=(const AlterationObserverRegistry&) {
       typename Container::iterator it;
       for (it = container.begin(); it != container.end(); ++it) {
@@ -204,7 +204,7 @@
     /// Destructor.
 				
-    /// Destructor of the AlterationObserverRegistry.
+    /// Destructor of the AlterationNotifier.
     ///
-    ~AlterationObserverRegistry() {
+    ~AlterationNotifier() {
       typename Container::iterator it;
       for (it = container.begin(); it != container.end(); ++it) {
@@ -309,22 +309,22 @@
 
     /// The edge observer registry.
-    typedef AlterationObserverRegistry<Edge> EdgeObserverRegistry;
+    typedef AlterationNotifier<Edge> EdgeObserverRegistry;
     /// The node observer registry.
-    typedef AlterationObserverRegistry<Node> NodeObserverRegistry;
+    typedef AlterationNotifier<Node> NodeObserverRegistry;
 
 
   protected:
 
-    mutable EdgeObserverRegistry edge_observers;
-
-    mutable NodeObserverRegistry node_observers;
-
-  public:
-
-    EdgeObserverRegistry& getObserverRegistry(Edge = INVALID) const {
+    mutable EdgeNotifier edge_observers;
+
+    mutable NodeNotifier node_observers;
+
+  public:
+
+    EdgeNotifier& getObserverRegistry(Edge = INVALID) const {
       return edge_observers;
     }
 
-    NodeObserverRegistry& getObserverRegistry(Node = INVALID) const {
+    NodeNotifier& getObserverRegistry(Node = INVALID) const {
       return node_observers;
     }
@@ -359,14 +359,14 @@
 
     /// The edge observer registry.
-    typedef AlterationObserverRegistry<UndirEdge> UndirEdgeObserverRegistry;
+    typedef AlterationNotifier<UndirEdge> UndirEdgeObserverRegistry;
 
   protected:
 
-    mutable UndirEdgeObserverRegistry undir_edge_observers;
-
-  public:
-
-    using Parent::getObserverRegistry;
-    UndirEdgeObserverRegistry& getObserverRegistry(UndirEdge) const {
+    mutable UndirEdgeNotifier undir_edge_observers;
+
+  public:
+
+    using Parent::getNotifier;
+    UndirEdgeNotifier& getObserverRegistry(UndirEdge) const {
       return undir_edge_observers;
     }
@@ -1,4 +1,4 @@
 /* -*- C++ -*-
- * src/lemon/observer_registry.h - Part of LEMON, a generic C++ optimization library
+ * src/lemon/notifier.h - Part of LEMON, a generic C++ optimization library
  *
  * Copyright (C) 2004 Egervary Jeno Kombinatorikus Optimalizalasi Kutatocsoport
@@ -37,5 +37,5 @@
   /// alterations in a container. The alteration observers can be attached
   /// to and detached from the registry. The observers have to inherit
-  /// from the \ref AlterationObserverRegistry::ObserverBase and override
+  /// from the \ref AlterationNotifier::ObserverBase and override
   /// the virtual functions in that.
   ///
@@ -179,21 +179,21 @@
 	
     ///
-    /// The default constructor of the AlterationObserverRegistry. 
+    /// The default constructor of the AlterationNotifier. 
     /// It creates an empty registry.
@@ -179,21 +179,21 @@
     /// Assign operator.
 		
-    /// Assign operator for the AlterationObserverRegistry. 
+    /// Assign operator for the AlterationNotifier. 
     /// It makes the registry only empty because the copiable
     /// registry's observers have to be registered still into that registry.
